# remirepo spec file for php-pecl-cassandra
#
# Copyright (c) 2015-2023 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please preserve changelog entries
#

%{?scl:%scl_package php-pecl-cassandra}

%bcond_without      tests

%global pecl_name   cassandra
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
#global prever      RC
# see https://github.com/datastax/php-driver/releases
#global gh_commit   84035aa9d81c7c3b53f2f3461949e2bbdd300f46
#global gh_short    %%(c=%%{gh_commit}; echo ${c:0:7})
%global gh_owner    datastax
%global gh_project  php-driver
%global ini_name    40-%{pecl_name}.ini
%if 0%{?gh_commit:1}
%global sources     %{gh_project}-%{gh_commit}/ext
%else
%global sources     %{pecl_name}-%{version}%{?prever}
%endif
%global _configure  ../%{sources}/configure

# We don't really rely on upstream ABI
%global buildver %(pkg-config --silence-errors --modversion cassandra 2>/dev/null || echo 65536)

Summary:      DataStax PHP Driver for Apache Cassandra
Name:         %{?scl_prefix}php-pecl-%{pecl_name}
Version:      1.3.2
Release:      13%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:      Apache-2.0
URL:          https://pecl.php.net/package/%{pecl_name}

# Pull sources from github to get tests
%if 0%{?gh_commit:1}
Source0:      https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{gh_project}-%{version}%{?prever}.tar.gz
%else
Source:       https://pecl.php.net/get/%{pecl_name}-%{version}%{?prever}.tgz
%endif

Patch0:       https://patch-diff.githubusercontent.com/raw/datastax/php-driver/pull/126.patch
Patch1:       https://patch-diff.githubusercontent.com/raw/datastax/php-driver/pull/132.patch
Patch2:       https://patch-diff.githubusercontent.com/raw/datastax/php-driver/pull/135.patch
Patch3:       https://patch-diff.githubusercontent.com/raw/datastax/php-driver/pull/141.patch
# Fix for PHP 8 from https://github.com/nano-interactive/cassandra-php-driver/commits/v1.3.x/ext
Patch4:       %{pecl_name}-php8.patch
Patch5:       https://patch-diff.githubusercontent.com/raw/nano-interactive/cassandra-php-driver/pull/29.patch
Patch6:       https://patch-diff.githubusercontent.com/raw/nano-interactive/cassandra-php-driver/pull/36.patch

BuildRequires: make
BuildRequires: %{?dtsprefix}gcc
BuildRequires: %{?scl_prefix}php-devel >= 5.6
BuildRequires: %{?scl_prefix}php-pear
BuildRequires: cassandra-cpp-driver-devel >= 2.7.0
BuildRequires: libuv-devel
BuildRequires: gmp-devel

Requires:     cassandra-cpp-driver%{?_isa}  >= %{buildver}
Requires:     %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:     %{?scl_prefix}php(api) = %{php_core_api}

Provides:     %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:     %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:     %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:     %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
A modern, feature-rich and highly tunable PHP client library for Apache
Cassandra and DataStax Enterprise using exclusively Cassandra's binary
protocol and Cassandra Query Language v3.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -c -q
%if 0%{?gh_commit:1}
mv %{sources}/package.xml .
%endif

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

pushd %{sources}
%patch -P0 -p2 -b .pr126
%patch -P1 -p2 -b .pr132
%patch -P2 -p2 -b .pr135
%patch -P3 -p2 -b .pr141
%patch -P4 -p2 -b .php8
%patch -P5 -p2 -b .php81
%patch -P6 -p2 -b .php82

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_DRIVER_VERSION /{s/.* "//;s/".*$//;p}' version.h)
if test "x${extver}" != "x%{version}%{?prever}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?prever}.
   exit 1
fi
popd

cat << 'EOF' | tee %{ini_name}
; Enable '%{summary}' extension module
extension=%{pecl_name}.so

; Configuration
;cassandra.log = 'cassandra.log'
;cassandra.log_level = 'ERROR'
EOF

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif


%build
%{?dtsenable}

export PHP_RPATH=no

pushd %{sources}
%{__phpize}
popd

pushd NTS
%configure  \
  --with-cassandra \
  --with-php-config=%{__phpconfig}
make %{?_smp_mflags}
popd

%if %{with_zts}
pushd ZTS
%configure  \
  --with-cassandra \
  --with-php-config=%{__ztsphpconfig}
make %{?_smp_mflags}
popd
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# Drop in the bit of configuration
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%check
cd %{sources}

: Minimal load test for NTS extension
%{__php} -n \
    -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    -m | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php -q --show-diff
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} -n \
    -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    -m | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php -q --show-diff
%endif
%endif


%files
%{?_licensedir:%license %{sources}/LICENSE}
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Fri Aug 18 2023 Remi Collet <remi@remirepo.net> - 1.3.2-13
- build out of sources tree

* Tue Feb 21 2023 Remi Collet <remi@remirepo.net> - 1.3.2-12
- spec cleanup, synced with fork version 1.3.8

* Fri Sep 16 2022 Remi Collet <remi@remirepo.net> - 1.3.2-11
- add patch for PHP 8.2 from
  https://github.com/nano-interactive/cassandra-php-driver/pull/36

* Wed Jun 15 2022 Remi Collet <remi@remirepo.net> - 1.3.2-10
- add patch for PHP 8 from extension fork
  https://github.com/nano-interactive/cassandra-php-driver/
- add patch for PHP 8.1 from
  https://github.com/nano-interactive/cassandra-php-driver/pull/29
- synced with fork version 1.3.7

* Wed Jan 15 2020 Remi Collet <remi@remirepo.net> - 1.3.2-9
- fix for cassandra-cpp-driver 2.15.0 with new headers location
  from https://github.com/datastax/php-driver/pull/141

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 1.3.2-8
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 1.3.2-7
- rebuild for 7.4.0beta1

* Wed May 29 2019 Remi Collet <remi@remirepo.net> - 1.3.2-6
- rebuild

* Thu May 23 2019 Remi Collet <remi@remirepo.net> - 1.3.2-5
- add patch for PHP 7.4 from
  https://github.com/datastax/php-driver/pull/132

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 1.3.2-4
- rebuild for 7.3.0beta2 new ABI

* Tue Jul 17 2018 Remi Collet <remi@remirepo.net> - 1.3.2-3
- rebuld for 7.3.0alpha4 new ABI

* Thu Jun 28 2018 Remi Collet <remi@remirepo.net> - 1.3.2-2
- add patch for [-Werror=format-security] from
  https://github.com/datastax/php-driver/pull/126

* Tue Aug 15 2017 Remi Collet <remi@remirepo.net> - 1.3.2-1
- Update to 1.3.2
- raise dependency on cassandra-cpp-driver 2.7.0

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 1.3.0-5
- rebuild for PHP 7.2.0beta1 new API

* Wed Jun 21 2017 Remi Collet <remi@remirepo.net> - 1.3.0-4
- rebuild for 7.2.0alpha2

* Tue May 30 2017 Remi Collet <remi@remirepo.net> - 1.3.0-3
- rebuild (for 7.2)

* Wed May 24 2017 Remi Collet <remi@fedoraproject.org> - 1.3.0-2
- rebuild against new cassandra-cpp-driver

* Thu Mar 16 2017 Remi Collet <remi@remirepo.net> - 1.3.0-1
- Update to 1.3.0
- raise dependency on PHP 5.6
- raise dependency on cassandra-cpp-driver >= 2.6.0

* Wed Jan  4 2017 Remi Collet <remi@fedoraproject.org> - 1.2.2-4
- rebuild against new libuv (EL-7)

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 1.2.2-3
- rebuild with PHP 7.1.0 GA

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 1.2.2-2
- rebuild for PHP 7.1 new API version

* Tue Aug 09 2016 Remi Collet <remi@fedoraproject.org> - 1.2.2-1
- Update to 1.2.2 (stable)

* Thu Jul 28 2016 Remi Collet <remi@fedoraproject.org> - 1.2.1-1
- Update to 1.2.1 (no change)

* Wed Jul 27 2016 Remi Collet <remi@fedoraproject.org> - 1.2.0-1
- Update to 1.2.0

* Fri Feb 12 2016 Remi Collet <remi@fedoraproject.org> - 1.1.0-1
- Update to 1.1.0

* Thu Nov 26 2015 Remi Collet <remi@fedoraproject.org> - 1.0.1-1
- Update to 1.0.1

* Tue Sep 15 2015 Remi Collet <remi@fedoraproject.org> - 1.0.0-1
- update to 1.0.0 (stable)

* Thu Aug 13 2015 Remi Collet <remi@fedoraproject.org> - 1.0.0-0.2.RC
- fix package name for more-php56

* Thu Aug 13 2015 Remi Collet <remi@fedoraproject.org> - 1.0.0-0.1.RC
- Initial package, version 1.0.0RC
